@@ -1,4 +1,4 @@
-from digital_experiments.core import current_directory, experiment
+from digital_experiments.core import current_directory, dont_record, experiment
 from digital_experiments.querying import (
     experiments_for,
     get_artefacts,
@@ -6,4 +6,4 @@ from digital_experiments.querying import (
     to_df,
 )
 
-__version__ = "0.1.8"
+__version__ = "0.1.9"
